Alpha

- configuration: local
- configurations
  - local
    - databases
      - sub_configuration: True
      - main: ALPHA
      - ALPHA
        - new: True
        - ini: True
        - path: C:\alpha\duranda1\configs\/back/src/alpha.sqlite
        - type: sqlite
        - init_database_dir_json: C:\alpha\duranda1\configs\/back/src/ini/ALPHA
        - init_database_dir_py: C:\Git\pyMES/tests/databases/ini
        - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/alpha.sqlite
      - FCM
        - new: True
        - path: C:\alpha\duranda1\configs\/back/src/fcm.sqlite
        - type: sqlite
        - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/fcm.sqlite
      - IFA
        - new: True
        - path: C:\alpha\duranda1\configs\/back/src/ifa.sqlite
        - type: sqlite
        - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/ifa.sqlite
      - DATAWARE
        - new: True
        - path: C:\alpha\duranda1\configs\/back/src/dw.sqlite
        - type: sqlite
        - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/dw.sqlite
      - PPDB
        - new: True
        - path: C:\alpha\duranda1\configs\/back/src/ppdb.sqlite
        - type: sqlite
        - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/ppdb.sqlite
      - configuration: local
      - run: C:\Git\pyMES
      - project: C:\Git\pyMES
      - user: duranda1
      - ip: 10.129.6.171
      - platform: Windows
      - root: C:\alpha\duranda1\configs\
  - dev
    - databases
      - sub_configuration: True
      - main: ALPHA
      - ALPHA
        - new: True
        - host: crx033.cro.st.com
        - password: STCrollesDev_38
        - user: alphadevadm
        - port: 1525
        - sid: FCM
        - type: oracle
      - FCM
        - new: True
        - host: crx033.cro.st.com
        - password: welcome_to_fcmdev0
        - user: fcmdev
        - port: 1525
        - sid: FCM
        - type: oracle
      - IFA
        - new: True
        - host: crx197.cro.st.com
        - user: ifaadm
        - password: ifaadm
        - port: 1532
        - sid: AUTO
        - type: oracle
      - DATAWARE
        - new: True
        - host: srv_dw.cro.st.com
        - user: dw_select
        - password: dw_select
        - port: 1524
        - sid: dw
        - type: oracle
      - configuration: local
      - run: C:\Git\pyMES
      - project: C:\Git\pyMES
      - user: duranda1
      - ip: 10.129.6.171
      - platform: Windows
      - root: C:\alpha\duranda1\configs\
  - prod
    - databases
      - sub_configuration: True
      - configuration: local
      - run: C:\Git\pyMES
      - project: C:\Git\pyMES
      - user: duranda1
      - ip: 10.129.6.171
      - platform: Windows
      - root: C:\alpha\duranda1\configs\
- loggers
  - auto
    - level: debug
    - cmd_output: True
  - vms
    - level: debug
    - cmd_output: True
  - processes
    - level: info
    - cmd_output: True
  - database
    - level: debug
  - locks
    - level: info
  - r8_to_crolles_ifa
    - level: info
  - cron
    - level: info
  - synchronize_ws
    - level: info
  - seqblk
    - level: info
  - test
    - level: debug
  - api
    - level: debug
- root: /alpha/duranda1
- home: /alpha/duranda1
- directories
  - data: /alpha/duranda1/data
  - logs: /alpha/duranda1/logs
  - tests: ['C:\\Git\\pyMES/tests']
- environment
  - NLS_LANG: FRENCH_FRANCE.WE8ISO8859P1
- platforms
  - windows
    - root: /alpha/duranda1
    - home: /alpha/duranda1
- run: C:\Git\pyMES
- project: C:\Git\pyMES
- user: duranda1
- ip: 10.129.6.171
- platform: Windows
- databases
  - sub_configuration: True
  - main: ALPHA
  - ALPHA
    - new: True
    - ini: True
    - path: C:\alpha\duranda1\configs\/back/src/alpha.sqlite
    - type: sqlite
    - init_database_dir_json: C:\alpha\duranda1\configs\/back/src/ini/ALPHA
    - init_database_dir_py: C:\Git\pyMES/tests/databases/ini
    - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/alpha.sqlite
  - FCM
    - new: True
    - path: C:\alpha\duranda1\configs\/back/src/fcm.sqlite
    - type: sqlite
    - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/fcm.sqlite
  - IFA
    - new: True
    - path: C:\alpha\duranda1\configs\/back/src/ifa.sqlite
    - type: sqlite
    - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/ifa.sqlite
  - DATAWARE
    - new: True
    - path: C:\alpha\duranda1\configs\/back/src/dw.sqlite
    - type: sqlite
    - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/dw.sqlite
  - PPDB
    - new: True
    - path: C:\alpha\duranda1\configs\/back/src/ppdb.sqlite
    - type: sqlite
    - cnx: sqlite:///C:\alpha\duranda1\configs\/back/src/ppdb.sqlite
  - configuration: local
  - run: C:\Git\pyMES
  - project: C:\Git\pyMES
  - user: duranda1
  - ip: 10.129.6.171
  - platform: Windows
  - root: C:\alpha\duranda1\configs\